@@ -1,4 +1,4 @@
-/* $Id: xfburn-adding-progress.h 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-adding-progress.h 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  * Copyright (c) 2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -47,7 +47,7 @@ typedef struct
   void (*adding_done) (XfburnAddingProgress *progress, XfburnDataComposition *dc);
 } XfburnAddingProgressClass;
 
-GtkType xfburn_adding_progress_get_type (void);
+GType xfburn_adding_progress_get_type (void);
 
 XfburnAddingProgress *xfburn_adding_progress_new (void);
 void xfburn_adding_progress_pulse (XfburnAddingProgress *adding_progress);
