@@ -1,4 +1,4 @@
-/* $Id: xfburn-audio-composition.c 6211 2008-11-27 00:00:39Z squisher $ */
+/* $Id: xfburn-audio-composition.c 7718 2009-07-13 03:24:04Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -119,6 +119,7 @@ static void composition_interface_init (XfburnCompositionInterface *composition,
 static void xfburn_audio_composition_init (XfburnAudioComposition *dc);
 static void xfburn_audio_composition_finalize (GObject * object);
 
+/* internals */
 static void show_custom_controls (XfburnComposition *composition);
 static void hide_custom_controls (XfburnComposition *composition);
 static void load_from_file (XfburnComposition *composition, const gchar *file);
@@ -190,6 +191,7 @@ typedef struct
   GtkWidget *content;
   GtkWidget *disc_usage;
   GtkWidget *progress;
+  GtkTreeStore *model;
 
   XfburnTranscoder *trans;
 } XfburnAudioCompositionPrivate;
@@ -232,10 +234,10 @@ static GdkPixbuf *icon_directory = NULL, *icon_file = NULL;
 /********************************/
 /* XfburnAudioComposition class */
 /********************************/
-GtkType
+GType
 xfburn_audio_composition_get_type (void)
 {
-  static GtkType audio_composition_type = 0;
+  static GType audio_composition_type = 0;
 
   if (!audio_composition_type) {
     static const GTypeInfo audio_composition_info = {
@@ -316,7 +318,7 @@ xfburn_audio_composition_init (XfburnAudioComposition * composition)
 
   GtkTargetEntry gte_src[] =  { { "XFBURN_TREE_PATHS", GTK_TARGET_SAME_WIDGET, AUDIO_COMPOSITION_DND_TARGET_INSIDE } };
   GtkTargetEntry gte_dest[] = { { "XFBURN_TREE_PATHS", GTK_TARGET_SAME_WIDGET, AUDIO_COMPOSITION_DND_TARGET_INSIDE },
-                                { "text/plain", 0, AUDIO_COMPOSITION_DND_TARGET_TEXT_PLAIN },
+                                { "text/plain;charset=utf-8", 0, AUDIO_COMPOSITION_DND_TARGET_TEXT_PLAIN },
                                 { "text/uri-list", 0, AUDIO_COMPOSITION_DND_TARGET_TEXT_URI_LIST },
                               };
 
@@ -382,8 +384,9 @@ xfburn_audio_composition_init (XfburnAudioComposition * composition)
 
   priv->content = exo_tree_view_new ();
   model = gtk_tree_store_new (AUDIO_COMPOSITION_N_COLUMNS, GDK_TYPE_PIXBUF, G_TYPE_UINT, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_STRING,
-                              G_TYPE_UINT64, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, G_TYPE_POINTER);
-							  
+                              G_TYPE_UINT64, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_UINT, XFBURN_TYPE_AUDIO_TRACK);
+  priv->model = model;
+
   /*
   gtk_tree_sortable_set_sort_func (GTK_TREE_SORTABLE (model), AUDIO_COMPOSITION_COLUMN_POS,
                                    song_tree_sortfunc, NULL, NULL);
@@ -502,10 +505,13 @@ xfburn_audio_composition_finalize (GObject * object)
     }
   }
 
-  /* FIXME: free XfburnAudioTracks */
-
   g_object_unref (priv->trans);
   priv->trans = NULL;
+
+  /* while the content treeview is part of the GUI and is automatically destroyed
+     when this tab is closed, it does not take ownership of the model, which then
+     must be unref'ed manually */
+  g_object_unref (priv->model);
   
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -877,7 +883,7 @@ remove_row_reference (GtkTreeRowReference *reference, XfburnAudioCompositionPriv
 {
   GtkTreePath *path = NULL;
   GtkTreeModel *model;
-  
+
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->content));
   
   path = gtk_tree_row_reference_get_path (reference);
@@ -911,6 +917,7 @@ remove_row_reference (GtkTreeRowReference *reference, XfburnAudioCompositionPriv
       */
       
       gtk_tree_store_remove (GTK_TREE_STORE (model), &iter);
+      priv->n_tracks--;
     }
     
     gtk_tree_path_free (path);
@@ -1229,12 +1236,12 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnAudioComposition * d
 
       gdk_threads_enter ();
       if (insertion != NULL) {
-        if (position == GTK_TREE_VIEW_DROP_AFTER)
+        if (position == GTK_TREE_VIEW_DROP_AFTER || position == GTK_TREE_VIEW_DROP_INTO_OR_AFTER)
           gtk_tree_store_insert_after (GTK_TREE_STORE (model), iter, NULL, insertion);
-        else if (position == GTK_TREE_VIEW_DROP_BEFORE)
+        else if (position == GTK_TREE_VIEW_DROP_BEFORE || position == GTK_TREE_VIEW_DROP_INTO_OR_BEFORE)
           gtk_tree_store_insert_before (GTK_TREE_STORE (model), iter, NULL, insertion);
         else
-          g_error ("I wasn't expecting this position!");
+          g_error ("Invalid position to drop item in!");
       } else
         gtk_tree_store_append (GTK_TREE_STORE (model), iter, NULL);
       gdk_threads_leave ();
@@ -1260,6 +1267,8 @@ thread_add_file_to_list_with_name (const gchar *name, XfburnAudioComposition * d
       gdk_threads_leave ();
 
       g_free (humanlength);
+      /* the tree store makes a copy of the boxed type, so we can free the original */
+      g_boxed_free (XFBURN_TYPE_AUDIO_TRACK, atrack);
 
       gdk_threads_enter ();
       xfburn_disc_usage_add_size (XFBURN_DISC_USAGE (priv->disc_usage), secs);
@@ -1679,26 +1688,50 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
     xfburn_default_cursor (priv->content);
   }
   /* drag from the file selector */
-  else if (sd->target == gdk_atom_intern ("text/plain", FALSE)) {
+  else if (sd->target == gdk_atom_intern ("text/plain;charset=utf-8", FALSE)) {
     ThreadAddFilesDragParams *params;
     const gchar *file = NULL;
     gboolean ret = FALSE;
+    gchar *full_paths;
 
     xfburn_adding_progress_show (XFBURN_ADDING_PROGRESS (priv->progress));
     
-    file = strtok ((gchar *) sd->data, "\n");
+    full_paths = (gchar *) gtk_selection_data_get_text (sd);
+
+    file = strtok ((gchar *) full_paths, "\n");
     while (file) {
       gchar *full_path;
 
+#ifdef HAVE_THUNAR_VFS
+      ThunarVfsPath *vfs_path;
+      GError *vfs_error = NULL;
+
+      vfs_path = thunar_vfs_path_new (file, &vfs_error);
+
+      if (vfs_error) {
+        g_warning ("Failed to create vfs path for '%s': %s", file, vfs_error->message);
+        g_error_free (vfs_error);
+        continue;
+      }
+
+      if (thunar_vfs_path_get_scheme (vfs_path) != THUNAR_VFS_PATH_SCHEME_FILE)
+        continue;
+      full_path = thunar_vfs_path_dup_string (vfs_path);
+
+      thunar_vfs_path_unref (vfs_path);
+
+#else /* no thunar-vfs */
+
       if (g_str_has_prefix (file, "file://"))
         full_path = g_build_filename (&file[7], NULL);
-      else if (g_str_has_prefix ((gchar *) sd->data, "file:"))
+      else if (g_str_has_prefix (file, "file:"))
         full_path = g_build_filename (&file[5], NULL);
       else
         full_path = g_build_filename (file, NULL);
 
       if (full_path[strlen (full_path) - 1] == '\r')
         full_path[strlen (full_path) - 1] = '\0';
+#endif
 
       /* remember path to add it later in another thread */
       priv->full_paths_to_add = g_list_append (priv->full_paths_to_add, full_path);
@@ -1714,6 +1747,7 @@ cb_content_drag_data_rcv (GtkWidget * widget, GdkDragContext * dc, guint x, guin
 
       file = strtok (NULL, "\n");
     }
+    g_free (full_paths);
 
     /* paths actually get sent to us in reverse order,
      * so no reverse is necessary to add them in the same order as selected.
