@@ -1,4 +1,4 @@
-/* $Id: xfburn-blank-dialog.h 5039 2008-07-09 18:45:08Z squisher $ */
+/* $Id: xfburn-blank-dialog.h 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -47,7 +47,7 @@ typedef struct
   XfceTitledDialogClass parent_class;
 } XfburnBlankDialogClass;
 
-GtkType xfburn_blank_dialog_get_type ();
+GType xfburn_blank_dialog_get_type ();
 GtkWidget *xfburn_blank_dialog_new ();
 GtkWidget * xfburn_blank_dialog_new_eject (gboolean eject);
 
