@@ -1,4 +1,4 @@
-/* $Id: xfburn-burn-data-dvd-composition-dialog.c 5403 2008-09-14 08:32:03Z squisher $ */
+/* $Id: xfburn-burn-data-dvd-composition-dialog.c 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  *  Copyright (c) 2007 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -56,10 +56,10 @@ static void xfburn_burn_data_dvd_composition_dialog_finalize (GObject * object);
 /* globals */
 static XfceTitledDialogClass *parent_class = NULL;
 
-GtkType
+GType
 xfburn_burn_data_dvd_composition_dialog_get_type ()
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
