@@ -1,4 +1,4 @@
-/* $Id: xfburn-burn-data-dvd-composition-dialog.h 4592 2008-04-16 14:58:48Z squisher $ */
+/* $Id: xfburn-burn-data-dvd-composition-dialog.h 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  *  Copyright (c) 2007 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -49,7 +49,7 @@ typedef struct
   XfburnBurnDataCompositionBaseDialogClass parent_class;
 } XfburnBurnDataDvdCompositionDialogClass;
 
-GtkType xfburn_burn_data_dvd_composition_dialog_get_type ();
+GType xfburn_burn_data_dvd_composition_dialog_get_type ();
 
 GtkWidget *xfburn_burn_data_dvd_composition_dialog_new (IsoImage *image);
 
