@@ -1,4 +1,4 @@
-/* $Id: xfburn-burn-image-dialog.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-burn-image-dialog.c 7718 2009-07-13 03:24:04Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *  Copyright (c) 2008      David Mohr (squisher@xfce.org)
@@ -74,8 +74,7 @@ static void xfburn_burn_image_dialog_class_init (XfburnBurnImageDialogClass * kl
 static void xfburn_burn_image_dialog_init (XfburnBurnImageDialog * sp);
 
 void burn_image_dialog_error (XfburnBurnImageDialog * dialog, const gchar * msg_error);
-static void cb_device_changed (XfburnDeviceBox *box, XfburnDevice *device, XfburnBurnImageDialog * dialog);
-static void cb_disc_refreshed (XfburnDeviceBox *box, XfburnDevice *device, XfburnBurnImageDialog * dialog);
+static void cb_volume_change_end (XfburnDeviceList *devlist, gboolean device_changed, XfburnDevice *device, XfburnBurnImageDialog * dialog);
 static void cb_dialog_response (XfburnBurnImageDialog * dialog, gint response_id, gpointer user_data);
 
 static void update_image_label (GtkFileChooser *chooser, XfburnBurnImageDialog * dialog);
@@ -88,10 +87,10 @@ static void cb_clicked_ok (GtkButton * button, gpointer user_data);
 /*********************/
 static XfceTitledDialogClass *parent_class = NULL;
 
-GtkType
+GType
 xfburn_burn_image_dialog_get_type ()
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -104,6 +103,7 @@ xfburn_burn_image_dialog_get_type ()
       sizeof (XfburnBurnImageDialog),
       0,
       (GInstanceInitFunc) xfburn_burn_image_dialog_init,
+      NULL
     };
 
     type = g_type_register_static (XFCE_TYPE_TITLED_DIALOG, "XfburnBurnImageDialog", &our_info, 0);
@@ -130,6 +130,7 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   GtkWidget *frame;
   GtkWidget *vbox;
   GtkWidget *button;
+  XfburnDeviceList *devlist;
   XfburnDevice *device;
 
   gtk_window_set_title (GTK_WINDOW (obj), _("Burn image"));
@@ -160,8 +161,7 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   priv->image_label = gtk_label_new ("");
   gtk_widget_show (priv->image_label);
   gtk_box_pack_start (GTK_BOX (box), priv->image_label, FALSE, FALSE, 0);
-  gtk_label_set_markup (GTK_LABEL(priv->image_label),
-  	                _("<span weight=\"bold\" foreground=\"darkred\" stretch=\"semiexpanded\">Please select an image to burn!</span>"));
+  update_image_label (GTK_FILE_CHOOSER (priv->chooser_image), obj);
   g_signal_connect (G_OBJECT (priv->chooser_image), "selection-changed", G_CALLBACK (update_image_label), obj);
     
   /* devices list */
@@ -208,14 +208,18 @@ xfburn_burn_image_dialog_init (XfburnBurnImageDialog * obj)
   gtk_widget_grab_focus (priv->burn_button);
   gtk_widget_grab_default (priv->burn_button);
 
-  g_signal_connect (G_OBJECT (priv->device_box), "device-changed", G_CALLBACK (cb_device_changed), obj);
-  g_signal_connect (G_OBJECT (priv->device_box), "disc-refreshed", G_CALLBACK (cb_disc_refreshed), obj);
+  devlist = xfburn_device_list_new ();
+
+  g_signal_connect (G_OBJECT (devlist), "volume-change-end", G_CALLBACK (cb_volume_change_end), obj);
   g_signal_connect (G_OBJECT (obj), "response", G_CALLBACK (cb_dialog_response), obj);
-  cb_disc_refreshed (XFBURN_DEVICE_BOX (priv->device_box), xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box)), obj);
+  device = xfburn_device_list_get_current_device (devlist);
+
+  cb_volume_change_end (devlist, TRUE, device, obj);
 
-  device = xfburn_device_box_get_selected_device (XFBURN_DEVICE_BOX (priv->device_box));
   if (device)
-    gtk_widget_set_sensitive (priv->check_dummy, device->dummy_write);
+    gtk_widget_set_sensitive (priv->check_dummy, xfburn_device_can_dummy_write (device));
+
+  g_object_unref (G_OBJECT (devlist));
 
 }
 
@@ -273,27 +277,23 @@ thread_burn_iso (ThreadBurnIsoParams * params)
   off_t fixed_size = 0;
   struct burn_source *data_src;
   struct burn_source *fifo_src;
+  int sectors[1];
 
   struct burn_drive *drive;
   struct burn_drive_info *drive_info = NULL;
   struct burn_write_opts * burn_options;
+  struct burn_source **fifos = NULL;
 
   gint ret;
 
-  if (!burn_initialize ()) {
-    g_critical ("Unable to initialize libburn");
-    g_free (params->iso_path);
-    g_free (params);
-    return;
-  }
-
   disc = burn_disc_create ();
   session = burn_session_create ();
   track = burn_track_create ();
 
   ret = burn_disc_add_session (disc, session, BURN_POS_END);
   if (ret == 0) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to create disc object"));
+    g_warning ("Unable to create disc object");
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("An error occurred in the burn backend"));
     goto end;
   }
 
@@ -306,29 +306,30 @@ thread_burn_iso (ThreadBurnIsoParams * params)
 	fixed_size = stbuf.st_size;
 
   if (fixed_size == 0) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to determine image size"));
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to determine image size."));
     goto end;
   }
 
   data_src = burn_fd_source_new(fd, -1, fixed_size);
 
   if (data_src == NULL) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Cannot open image"));
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Cannot open image."));
     goto end;
   }
 
-  fifo_src = burn_fifo_source_new (data_src, 2048, xfburn_settings_get_int ("fifo-size", XFBURN_FIFO_DEFAULT_SIZE) / 2, 0);
+  fifo_src = burn_fifo_source_new (data_src, 2048, xfburn_settings_get_int ("fifo-size", FIFO_DEFAULT_SIZE) / 2, 0);
   burn_source_free (data_src);
 
   if (burn_track_set_source (track, fifo_src) != BURN_SOURCE_OK) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Cannot attach source object to track object"));
+    g_warning ("Cannot attach source object to track object");
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("An error occurred in the burn backend"));
     goto end;
   }
   
   burn_session_add_track (session, track, BURN_POS_END);
 
   if (!xfburn_device_grab (params->device, &drive_info)) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to grab drive"));
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Unable to grab the drive."));
 
     goto end;
   }
@@ -337,25 +338,34 @@ thread_burn_iso (ThreadBurnIsoParams * params)
 
   burn_options = make_burn_options (params, drive);
   if (burn_options == NULL) {
-    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Burn mode is not currently implemented"));
+    xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("Burn mode is not currently implemented."));
     goto cleanup;
   }
 
   DBG ("Set speed to %d kb/s", params->speed);
   burn_drive_set_speed (drive, 0, params->speed);
 
+  // this assumes that an iso image can only have one track
+  sectors[0] = burn_disc_get_sectors (disc);
+  
   xfburn_progress_dialog_set_status_with_text (XFBURN_PROGRESS_DIALOG (dialog_progress), XFBURN_PROGRESS_DIALOG_STATUS_RUNNING, _("Burning image..."));
-  xfburn_perform_burn_write (dialog_progress, drive, params->write_mode, burn_options, disc, fifo_src);
+
+  fifos = g_new(struct burn_source *,1);
+  fifos[0] = fifo_src;
+
+  xfburn_perform_burn_write (dialog_progress, drive, params->write_mode, burn_options, DATA_BYTES_PER_SECTOR, disc, fifos, sectors);
+
+  g_free (fifos);
+
   burn_source_free (fifo_src);
   burn_write_opts_free (burn_options);
 
  cleanup:
-  burn_drive_release (drive, params->eject ? 1 : 0);
+  xfburn_device_release (drive_info, params->eject);
  end:
   burn_track_free (track);
   burn_session_free (session);
   burn_disc_free (disc);
-  burn_finish ();
 
   g_free (params->iso_path);
   g_free (params);
@@ -371,16 +381,12 @@ burn_image_dialog_error (XfburnBurnImageDialog * dialog, const gchar * msg_error
 }
 
 static void
-cb_device_changed (XfburnDeviceBox *box, XfburnDevice *device, XfburnBurnImageDialog * dialog) 
+cb_volume_change_end (XfburnDeviceList *devlist, gboolean device_changed, XfburnDevice *device, XfburnBurnImageDialog * dialog)
 {
   XfburnBurnImageDialogPrivate *priv = XFBURN_BURN_IMAGE_DIALOG_GET_PRIVATE (dialog);
 
-  gtk_widget_set_sensitive (priv->check_dummy, device->dummy_write);
-}
-
-static void
-cb_disc_refreshed (XfburnDeviceBox *box, XfburnDevice *device, XfburnBurnImageDialog * dialog) 
-{
+  if (device_changed)
+    gtk_widget_set_sensitive (priv->check_dummy, xfburn_device_can_dummy_write (device));
   check_burn_button (dialog);
 }
 
@@ -413,7 +419,7 @@ update_image_label (GtkFileChooser *chooser, XfburnBurnImageDialog * dialog)
 
   if (gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser)) == NULL) {
     gtk_label_set_markup (GTK_LABEL(priv->image_label),
-                          _("<span weight=\"bold\" foreground=\"darkred\" stretch=\"semiexpanded\">Please select an image to burn!</span>"));   
+                          _("<span weight=\"bold\" foreground=\"darkred\" stretch=\"semiexpanded\">Please select an image to burn</span>"));   
   } else {
     gtk_label_set_text (GTK_LABEL(priv->image_label), "");
     check_burn_button (dialog);
@@ -447,7 +453,7 @@ check_media (XfburnBurnImageDialog * dialog, ThreadBurnIsoParams *params, struct
   while (burn_drive_get_status (drive, NULL) != BURN_DRIVE_IDLE)
     usleep(100001);
 
-  /* Evaluate drive and media */
+  /* Evaluate drive and disc */
   while ((disc_state = burn_disc_get_status(drive)) == BURN_DISC_UNREADY)
     usleep(100001);
   if (disc_state == BURN_DISC_APPENDABLE && params->write_mode != WRITE_MODE_TAO) {
@@ -455,27 +461,27 @@ check_media (XfburnBurnImageDialog * dialog, ThreadBurnIsoParams *params, struct
     return FALSE;
   } else if (disc_state != BURN_DISC_BLANK) {
     if (disc_state == BURN_DISC_FULL)
-      burn_image_dialog_error (dialog, _("Closed media with data detected. Need blank or appendable media"));
+      burn_image_dialog_error (dialog, _("Closed disc with data detected. Need blank or appendable disc"));
     else if (disc_state == BURN_DISC_EMPTY) 
-      burn_image_dialog_error (dialog, _("No media detected in drive"));
+      burn_image_dialog_error (dialog, _("No disc detected in drive"));
     else {
-      burn_image_dialog_error (dialog, _("Cannot recognize state of drive and media"));
+      burn_image_dialog_error (dialog, _("Cannot recognize state of drive and disc"));
       DBG ("disc_state = %d", disc_state);
     }
     return FALSE;
   }
 
-  /* check if the image fits on the inserted media */
+  /* check if the image fits on the inserted disc */
   ret = stat (params->iso_path, &st);
   if (ret == 0) {
     off_t disc_size;
     disc_size = burn_disc_available_space (drive, burn_options);
     if (st.st_size > disc_size) {
-      burn_image_dialog_error (dialog, _("The selected image does not fit on the inserted disc!"));
+      burn_image_dialog_error (dialog, _("The selected image does not fit on the inserted disc"));
       return FALSE;
     }
   } else {
-    burn_image_dialog_error (dialog, _("Failed to get image size!"));
+    burn_image_dialog_error (dialog, _("Failed to get image size"));
     return FALSE;
   }
 
@@ -522,17 +528,11 @@ cb_clicked_ok (GtkButton *button, gpointer user_data)
   params->dummy = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_dummy));
   params->burnfree = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->check_burnfree));
   
-  if (!burn_initialize ()) {
-    g_critical ("Unable to initialize libburn");
-    return;
-  }
-
   if (!xfburn_device_grab (device, &drive_info)) {
-    burn_image_dialog_error (dialog, _("Unable to grab drive"));
+    burn_image_dialog_error (dialog, _("Unable to grab the drive."));
 
     g_free (params->iso_path);
     g_free (params);
-    burn_finish ();
     return;
   }
 
@@ -546,8 +546,7 @@ cb_clicked_ok (GtkButton *button, gpointer user_data)
     burn_write_opts_free (burn_options);
   }
 
-  burn_drive_release (drive_info->drive, 0);
-  burn_finish ();
+  xfburn_device_release (drive_info, 0);
 
   priv->params = params;
 
