@@ -1,4 +1,4 @@
-/* $Id: xfburn-composition.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-composition.c 5403 2008-09-14 08:32:03Z squisher $ */
 /*
  * Copyright (c) 2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -63,7 +63,8 @@ xfburn_composition_get_type (void)
       NULL,                          /* class_data */
       0,
       0,                             /* n_preallocs */
-      NULL                           /* instance_init */
+      NULL,                          /* instance_init */
+      NULL
     };
     
     type = g_type_register_static (G_TYPE_INTERFACE, "XfburnComposition", &info, 0);
