@@ -1,4 +1,4 @@
-/* $Id: xfburn-compositions-notebook.h 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-compositions-notebook.h 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -23,7 +23,6 @@
 #include <gtk/gtk.h>
 
 #include "xfburn-main-window.h"
-#include "xfburn-welcome-tab.h"
 #include "xfburn-composition.h"
 
 G_BEGIN_DECLS
@@ -46,17 +45,17 @@ typedef struct
 
 typedef enum
 {
-  XFBURN_WELCOME_TAB,
   XFBURN_DATA_COMPOSITION,
   XFBURN_AUDIO_COMPOSITION,
 } XfburnCompositionType;
 
-GtkType xfburn_compositions_notebook_get_type ();
+GType xfburn_compositions_notebook_get_type ();
 
 GtkWidget *xfburn_compositions_notebook_new ();
 
 XfburnComposition *xfburn_compositions_notebook_add_composition (XfburnCompositionsNotebook *notebook, XfburnCompositionType type);
-XfburnWelcomeTab *xfburn_compositions_notebook_add_welcome_tab (XfburnCompositionsNotebook *notebook, XfburnMainWindow *window);
+void xfburn_compositions_notebook_add_welcome_tab (XfburnCompositionsNotebook *notebook, GtkActionGroup *action_group);
+
 void xfburn_compositions_notebook_close_composition (XfburnCompositionsNotebook *notebook);
 
 void xfburn_compositions_notebook_load_composition (XfburnCompositionsNotebook *notebook, const gchar *file);
