@@ -1,4 +1,4 @@
-/* $Id: xfburn-copy-cd-dialog.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-copy-cd-dialog.c 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -65,10 +65,10 @@ static void cb_dialog_response (XfburnCopyCdDialog * dialog, gint response_id, X
 /*********************/
 static XfceTitledDialogClass *parent_class = NULL;
 
-GtkType
+GType
 xfburn_copy_cd_dialog_get_type ()
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -81,6 +81,7 @@ xfburn_copy_cd_dialog_get_type ()
       sizeof (XfburnCopyCdDialog),
       0,
       (GInstanceInitFunc) xfburn_copy_cd_dialog_init,
+      NULL
     };
 
     type = g_type_register_static (XFCE_TYPE_TITLED_DIALOG, "XfburnCopyCdDialog", &our_info, 0);
