@@ -1,4 +1,4 @@
-/* $Id: xfburn-copy-cd-progress-dialog.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-copy-cd-progress-dialog.c 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -42,10 +42,10 @@ static void cb_new_output (XfburnCopyCdProgressDialog * dialog, const gchar * ou
 /*********************/
 static XfburnProgressDialogClass *parent_class = NULL;
 
-GtkType
+GType
 xfburn_copy_cd_progress_dialog_get_type ()
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -58,6 +58,7 @@ xfburn_copy_cd_progress_dialog_get_type ()
       sizeof (XfburnCopyCdProgressDialog),
       0,
       (GInstanceInitFunc) xfburn_copy_cd_progress_dialog_init,
+      NULL
     };
 
     type = g_type_register_static (XFBURN_TYPE_PROGRESS_DIALOG, "XfburnCopyCdProgressDialog", &our_info, 0);
@@ -102,7 +103,7 @@ cb_new_output (XfburnCopyCdProgressDialog * dialog, const gchar * output, gpoint
     GtkWidget *dialog_confirm;
 
     dialog_confirm = gtk_message_dialog_new (GTK_WINDOW (dialog), GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                                             GTK_MESSAGE_INFO, GTK_BUTTONS_OK, _("Please insert a recordable medium."));
+                                             GTK_MESSAGE_INFO, GTK_BUTTONS_OK, _("Please insert a recordable disc."));
     gtk_dialog_run (GTK_DIALOG (dialog_confirm));
     gtk_widget_destroy (dialog_confirm);
     xfburn_progress_dialog_write_input (XFBURN_PROGRESS_DIALOG (dialog), "\n");
