@@ -1,4 +1,4 @@
-/* $Id: xfburn-create-iso-progress-dialog.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-create-iso-progress-dialog.c 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -42,10 +42,10 @@ static void cb_new_output (XfburnCreateIsoProgressDialog * dialog, const gchar *
 /*********************/
 static XfburnProgressDialogClass *parent_class = NULL;
 
-GtkType
+GType
 xfburn_create_iso_progress_dialog_get_type ()
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -58,6 +58,7 @@ xfburn_create_iso_progress_dialog_get_type ()
       sizeof (XfburnCreateIsoProgressDialog),
       0,
       (GInstanceInitFunc) xfburn_create_iso_progress_dialog_init,
+      NULL
     };
 
     type = g_type_register_static (XFBURN_TYPE_PROGRESS_DIALOG, "XfburnCreateIsoProgressDialog", &our_info, 0);
