@@ -1,4 +1,4 @@
-/* $Id: xfburn-data-composition.h 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-data-composition.h 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -49,9 +49,10 @@ enum
 {
   DATA_COMPOSITION_DND_TARGET_INSIDE,
   DATA_COMPOSITION_DND_TARGET_TEXT_PLAIN,
+  DATA_COMPOSITION_DND_TARGET_TEXT_URI_LIST,
 };
 
-GtkType xfburn_data_composition_get_type (void);
+GType xfburn_data_composition_get_type (void);
 
 GtkWidget *xfburn_data_composition_new (void);
 void xfburn_data_composition_add_files (XfburnDataComposition *content, int filec, char **filenames);
