@@ -1,4 +1,4 @@
-/* $Id: xfburn-device-box.h 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-device-box.h 7718 2009-07-13 03:24:04Z squisher $ */
 /*
  * Copyright (c) 2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -45,9 +45,8 @@ typedef struct
 typedef struct
 {
   GtkVBoxClass parent_class;
-  
-  void (*device_changed) (XfburnDeviceBox *box, XfburnDevice *device);
-  void (*disc_refreshed) (XfburnDeviceBox *box, XfburnDevice *device);
+
+  void (*volume_changed) (XfburnDeviceBox *box, gboolean device_changed, XfburnDevice *device);
 } XfburnDeviceBoxClass;
 
 typedef enum
@@ -62,6 +61,7 @@ typedef enum
   SHOW_SPEED_SELECTION = 1 << 7,
   SHOW_MODE_SELECTION = 1 << 8,
   BLANK_MODE = 1 << 9,
+  ACCEPT_ONLY_CD = 1 << 10,
 } XfburnDeviceBoxFlags;
 
 typedef enum
@@ -74,11 +74,10 @@ typedef enum
   WRITE_MODE_PACKET,
 } XfburnWriteMode;
 
-GtkType xfburn_device_box_get_type (void);
+GType xfburn_device_box_get_type (void);
 
 GtkWidget *xfburn_device_box_new (XfburnDeviceBoxFlags);
 
-gchar *xfburn_device_box_get_selected (XfburnDeviceBox *box);
 XfburnDevice *xfburn_device_box_get_selected_device (XfburnDeviceBox *box);
 
 gint xfburn_device_box_get_speed (XfburnDeviceBox *box);
