@@ -1,4 +1,4 @@
-/* $Id: xfburn-notebook-tab.h 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-notebook-tab.h 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -43,11 +43,14 @@ typedef struct
   void (*button_close_clicked) (XfburnNotebookTab *tab);
 } XfburnNotebookTabClass;
 
-GtkType xfburn_notebook_tab_get_type ();
+GType xfburn_notebook_tab_get_type ();
 
-GtkWidget *xfburn_notebook_tab_new (const gchar *label);
+GtkWidget *xfburn_notebook_tab_new (const gchar *label, gboolean show_button_close);
 
 void xfburn_notebook_tab_set_label (XfburnNotebookTab *tab, const gchar *label);
 
+void xfburn_notebook_tab_show_button_close (XfburnNotebookTab *tab);
+void xfburn_notebook_tab_show_button_hide (XfburnNotebookTab *tab);
+
 G_END_DECLS
 #endif /* XFBURN_NOTEBOOK_TAB_H */
