@@ -28,6 +28,7 @@
 
 #include "xfburn-perform-burn.h"
 #include "xfburn-progress-dialog.h"
+#include "xfburn-utils.h"
 
 /*************/
 /* internals */
@@ -69,6 +70,7 @@ xfburn_perform_burn_write (GtkWidget *dialog_progress,
   int dbg_no;
   int total_sectors, burned_sectors;
   off_t disc_size;
+  int disc_sectors;
   gboolean stopping = FALSE;
 
   while (burn_drive_get_status (drive, NULL) != BURN_DRIVE_IDLE)
@@ -108,13 +110,17 @@ xfburn_perform_burn_write (GtkWidget *dialog_progress,
   total_sectors = burn_disc_get_sectors (disc);
 
   disc_size = burn_disc_available_space (drive, burn_options);
-  if (disc_size < ((off_t)total_sectors * sector_size)) {
+
+  /* available_space assumes data tracks, so we'll just compare sectors */
+  disc_sectors = disc_size / DATA_BYTES_PER_SECTOR;
+
+  if (disc_sectors < total_sectors) {
     xfburn_progress_dialog_burning_failed (XFBURN_PROGRESS_DIALOG (dialog_progress), _("There is not enough space available on the inserted disc."));
     return;
   }
 
   /* set us up to receive libburn errors */
-  xfburn_device_list_capture_messages ();
+  xfburn_capture_libburn_messages ();
 
   /* Install the default libburn abort signal handler.
    * Hopefully this means the drive won't be left in a burning state if we catch a signal */
@@ -289,7 +295,7 @@ xfburn_perform_burn_write (GtkWidget *dialog_progress,
   if (ret < 0)
     g_warning ("Fatal error while trying to retrieve libburn message!");
 
-  xfburn_device_list_console_messages ();
+  xfburn_console_libburn_messages ();
 
   percent = (gdouble) progress.buffer_min_fill / (gdouble) progress.buffer_capacity;
   xfburn_progress_dialog_set_buffer_bar_min_fill (XFBURN_PROGRESS_DIALOG (dialog_progress), percent);
