@@ -1,4 +1,4 @@
-/* $Id: xfburn-preferences-dialog.c 6779 2009-02-25 02:12:30Z squisher $ */
+/* $Id: xfburn-preferences-dialog.c 7700 2009-07-08 23:33:05Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -56,6 +56,7 @@ static void xfburn_preferences_dialog_init (XfburnPreferencesDialog * sp);
 static void refresh_devices_list (XfburnPreferencesDialog * dialog);
 static void scan_button_clicked_cb (GtkWidget * button, gpointer user_data);
 static void xfburn_preferences_dialog_response_cb (XfburnPreferencesDialog * dialog, guint response_id, XfburnPreferencesDialogPrivate * priv);
+static void cb_show_hidden_clicked (GtkButton * Button, gpointer user_data);
 
 enum {
   SETTINGS_LIST_PIXBUF_COLUMN,
@@ -86,10 +87,10 @@ typedef struct
 /*********************************/
 static XfceTitledDialogClass *parent_class = NULL;
 
-GtkType
+GType
 xfburn_preferences_dialog_get_type ()
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -207,6 +208,7 @@ xfburn_preferences_dialog_init (XfburnPreferencesDialog * obj)
   priv->check_show_hidden = gtk_check_button_new_with_mnemonic (_("Show _hidden files"));
   gtk_box_pack_start (GTK_BOX (vbox2), priv->check_show_hidden, FALSE, FALSE, BORDER);
   gtk_widget_show (priv->check_show_hidden);
+  g_signal_connect (G_OBJECT (priv->check_show_hidden), "clicked", G_CALLBACK (cb_show_hidden_clicked), NULL);
 
   priv->check_show_human_readable = gtk_check_button_new_with_mnemonic (_("Show human_readable filesizes"));
   gtk_box_pack_start (GTK_BOX (vbox2), priv->check_show_human_readable, FALSE, FALSE, BORDER);
@@ -403,25 +405,40 @@ refresh_devices_list (XfburnPreferencesDialog * dialog)
   XfburnPreferencesDialogPrivate *priv = XFBURN_PREFERENCES_DIALOG_GET_PRIVATE (dialog);
   GtkTreeModel *model;
   GList *device;
+  XfburnDeviceList *devlist;
 
   model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->treeview_devices));
 
   gtk_list_store_clear (GTK_LIST_STORE (model));
 
-  device = xfburn_device_list_get_list ();
+  devlist = xfburn_device_list_new ();
+  g_object_get (G_OBJECT (devlist), "devices", &device, NULL);
+  g_object_unref (devlist);
+
   while (device) {
     GtkTreeIter iter;
     XfburnDevice *device_data;
+    gchar *name, *addr;
+    gboolean cdr, cdrw, dvdr, dvdram;
 
     device_data = (XfburnDevice *) device->data;
 
+    g_object_get (G_OBJECT (device_data), "name", &name, "address", &addr,
+                  "cdr", &cdr, "cdrw", &cdrw, "dvdr", &dvdr, "dvdram", &dvdram,
+                  NULL);
+
     gtk_list_store_append (GTK_LIST_STORE (model), &iter);
     gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-                        DEVICE_LIST_COLUMN_NAME, device_data->name,
-                        DEVICE_LIST_COLUMN_NODE, device_data->addr,
-                        DEVICE_LIST_COLUMN_CDR, device_data->cdr,
-                        DEVICE_LIST_COLUMN_CDRW, device_data->cdrw,
-                        DEVICE_LIST_COLUMN_DVDR, device_data->dvdr, DEVICE_LIST_COLUMN_DVDRAM, device_data->dvdram, -1);
+                        DEVICE_LIST_COLUMN_NAME, name,
+                        DEVICE_LIST_COLUMN_NODE, addr,
+                        DEVICE_LIST_COLUMN_CDR, cdr,
+                        DEVICE_LIST_COLUMN_CDRW, cdrw,
+                        DEVICE_LIST_COLUMN_DVDR, dvdr, 
+                        DEVICE_LIST_COLUMN_DVDRAM, dvdram, 
+                        -1);
+
+    g_free (name);
+    g_free (addr);
 
     device = g_list_next (device);
   }
@@ -438,10 +455,15 @@ xfburn_preferences_dialog_response_cb (XfburnPreferencesDialog * dialog, guint r
 static void
 scan_button_clicked_cb (GtkWidget * button, gpointer user_data)
 {
-  xfburn_device_list_init ();
   refresh_devices_list (user_data);
 }
 
+static void 
+cb_show_hidden_clicked (GtkButton * Button, gpointer user_data)
+{
+  xfce_warn (_("Changing this setting only takes full effect after a program restart."));
+}
+
 /* public */
 GtkWidget *
 xfburn_preferences_dialog_new ()
