@@ -1,4 +1,4 @@
-/* $Id: xfburn-preferences-dialog.h 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-preferences-dialog.h 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  * Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -44,7 +44,7 @@ typedef struct
 
 
 
-GtkType xfburn_preferences_dialog_get_type ();
+GType xfburn_preferences_dialog_get_type ();
 GtkWidget *xfburn_preferences_dialog_new ();
 
 G_END_DECLS
