@@ -1,4 +1,4 @@
-/* $Id: xfburn-progress-dialog.c 6049 2008-11-10 06:29:00Z squisher $ */
+/* $Id: xfburn-progress-dialog.c 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -111,10 +111,10 @@ xfburn_progress_dialog_status_get_type (void)
 /*                       */
 static GtkDialogClass *parent_class = NULL;
 
-GtkType
+GType
 xfburn_progress_dialog_get_type ()
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
