@@ -1,4 +1,4 @@
-/* $Id: xfburn-progress-dialog.h 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-progress-dialog.h 7506 2009-06-09 01:47:30Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -33,6 +33,7 @@ G_BEGIN_DECLS
 #define XFBURN_TYPE_PROGRESS_DIALOG_STATUS (xfburn_progress_dialog_status_get_type ())
 typedef enum
 {
+  XFBURN_PROGRESS_DIALOG_STATUS_STOPPING,
   XFBURN_PROGRESS_DIALOG_STATUS_RUNNING,
   XFBURN_PROGRESS_DIALOG_STATUS_FAILED,
   XFBURN_PROGRESS_DIALOG_STATUS_CANCELLED,
@@ -61,7 +62,7 @@ typedef struct
 } XfburnProgressDialogClass;
 
 
-GtkType xfburn_progress_dialog_get_type ();
+GType xfburn_progress_dialog_get_type ();
 
 void xfburn_progress_dialog_show_buffers (XfburnProgressDialog * dialog, gboolean show);
 void xfburn_progress_dialog_pulse_progress_bar (XfburnProgressDialog * dialog);
