@@ -1,4 +1,4 @@
-/* $Id: xfburn-stock.c 5095 2008-07-15 15:05:01Z squisher $ */
+/* $Id: xfburn-stock.c 5931 2008-11-03 06:14:41Z squisher $ */
 /*
  * Copyright (c) 2006 Jean-François Wauthy (pollux@xfce.org)
  *
@@ -33,10 +33,12 @@ static const gchar *xfburn_stock_icons[] = {
   XFBURN_STOCK_AUDIO_COPY,
   XFBURN_STOCK_BLANK_CDRW,
   XFBURN_STOCK_FORMAT_DVDRW,
+  XFBURN_STOCK_AUDIO_CD,
   XFBURN_STOCK_BURN_CD,
   XFBURN_STOCK_CD,
   XFBURN_STOCK_DATA_COPY,
   XFBURN_STOCK_IMPORT_SESSION,
+  XFBURN_STOCK_NEW_DATA_COMPOSITION,
 };
 
 void
