@@ -1,4 +1,4 @@
-/* $Id: xfburn-transcoder-gst.c 6469 2009-01-16 04:23:44Z squisher $ */
+/* $Id: xfburn-transcoder-gst.c 7563 2009-06-14 05:44:05Z squisher $ */
 /*
  *  Copyright (c) 2005-2006 Jean-François Wauthy (pollux@xfce.org)
  *  Copyright (c) 2008      David Mohr (dmohr@mcbf.net)
@@ -49,6 +49,8 @@
 #include "xfburn-settings.h"
 
 #include "xfburn-transcoder-gst.h"
+#include "xfburn-audio-track.h"
+#include "xfburn-audio-track-gst.h"
 
 
 /* 
@@ -74,14 +76,13 @@ static void delete_pipeline (XfburnTranscoderGst *trans);
 static void recreate_pipeline (XfburnTranscoderGst *trans);
 static const gchar * get_name (XfburnTranscoder *trans);
 static const gchar * get_description (XfburnTranscoder *trans);
-static XfburnAudioTrack * get_audio_track (XfburnTranscoder *trans, const gchar *fn, GError **error);
+static gboolean get_audio_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error);
 
 static struct burn_track * create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error);
 
 static gboolean prepare (XfburnTranscoder *trans, GError **error);
 static gboolean transcode_next_track (XfburnTranscoderGst *trans, GError **error);
 static void finish (XfburnTranscoder *trans);
-static gboolean free_burning_resources (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error);
 
 static gboolean is_initialized (XfburnTranscoder *trans, GError **error);
 
@@ -111,7 +112,7 @@ typedef enum {
 
 typedef struct {
   GstElement *pipeline;
-  GstElement *source, *decoder, *conv, *sink;
+  GstElement *source, *decoder, *resample, *conv, *sink;
 
   XfburnTranscoderGstState state;
   GCond *gst_cond;
@@ -127,12 +128,6 @@ typedef struct {
 } XfburnTranscoderGstPrivate;
 
 
-typedef struct {
-  int fd_in;
-  off_t size;
-} XfburnAudioTrackGst;
-
-
 /* constants */
 
 #define SIGNAL_WAIT_TIMEOUT_MICROS 1500000
@@ -160,10 +155,10 @@ static const gchar *errormsg_libburn_setup = "An error occurred while setting th
 static GObject *parent_class = NULL;
 //static guint signals[LAST_SIGNAL];
 
-GtkType
+GType
 xfburn_transcoder_gst_get_type ()
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0) {
     static const GTypeInfo our_info = {
@@ -249,7 +244,7 @@ transcoder_interface_init (XfburnTranscoderInterface *iface, gpointer iface_data
   iface->is_initialized = is_initialized;
   iface->get_audio_track = get_audio_track;
   iface->create_burn_track = create_burn_track;
-  iface->free_burning_resources = free_burning_resources;
+  /* free_burning_resources is not needed */
   iface->finish = finish;
   iface->prepare = prepare;
 }
@@ -263,7 +258,7 @@ create_pipeline (XfburnTranscoderGst *trans)
 {
   XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (trans);
 
-  GstElement *pipeline, *source, *decoder, *conv, *sink;
+  GstElement *pipeline, *source, *decoder, *resample, *conv, *sink;
 #if DEBUG_GST > 0 && DEBUG > 0
   GstElement *id;
 #endif
@@ -276,6 +271,7 @@ create_pipeline (XfburnTranscoderGst *trans)
 
   priv->source  = source   = gst_element_factory_make ("filesrc",       "file-source");
   priv->decoder = decoder  = gst_element_factory_make ("decodebin",     "decoder");
+  priv->resample= resample = gst_element_factory_make ("audioresample", "resampler");
   priv->conv    = conv     = gst_element_factory_make ("audioconvert",  "converter");
 #if DEBUG_GST > 0 && DEBUG > 0
                   id       = gst_element_factory_make ("identity",      "debugging-identity");
@@ -284,7 +280,7 @@ create_pipeline (XfburnTranscoderGst *trans)
   //priv->sink    = sink     = gst_element_factory_make ("fakesink",        "audio-output");
   //DBG ("\npipeline = %p\nsource = %p\ndecoder = %p\nconv = %p\nsink = %p", pipeline, source, decoder, conv, sink);
 
-  if (!pipeline || !source || !decoder || !conv || !sink) {
+  if (!pipeline || !source || !decoder || !resample || !conv || !sink) {
     g_warning ("A pipeline element could not be created");
     g_set_error (&(priv->error), XFBURN_ERROR, XFBURN_ERROR_GST_CREATION,
 		    "%s",
@@ -309,12 +305,13 @@ create_pipeline (XfburnTranscoderGst *trans)
   gst_object_unref (bus);
 
   gst_bin_add_many (GST_BIN (pipeline),
-                    source, decoder, conv, sink, NULL);
+                    source, decoder, resample, conv, sink, NULL);
 #if DEBUG_GST > 0 && DEBUG > 0
   gst_bin_add (GST_BIN (pipeline), id);
 #endif
 
   gst_element_link (source, decoder);
+  gst_element_link (resample, conv);
 
   /* setup caps for raw pcm data */
   caps = gst_caps_new_simple ("audio/x-raw-int",
@@ -662,7 +659,7 @@ on_pad_added (GstElement *element, GstPad *pad, gboolean last, gpointer data)
   GstCaps *caps;
   GstStructure *str;
   GstPad *audiopad;
-  GstElement *audio = (GstElement *) priv->conv;
+  GstElement *audio = (GstElement *) priv->resample;
 
   // only link once
   audiopad = gst_element_get_static_pad (audio, "sink");
@@ -761,24 +758,23 @@ cb_handoff (GstElement *element, GstBuffer *buffer, gpointer data)
 #endif
 
 
-static XfburnAudioTrack *
-get_audio_track (XfburnTranscoder *trans, const gchar *fn, GError **error)
+static gboolean
+get_audio_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error)
 {
   XfburnTranscoderGst *tgst = XFBURN_TRANSCODER_GST (trans);
   XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (tgst);
 
-  XfburnAudioTrack *atrack;
   XfburnAudioTrackGst *gtrack;
   GTimeVal tv;
   off_t size;
 
   priv->is_audio = FALSE;
 #if DEBUG_GST > 0
-  DBG ("Querying GST about %s", fn);
+  DBG ("Querying GST about %s", atrack->inputfile);
 #endif
 
   priv->state = XFBURN_TRANSCODER_GST_STATE_IDENTIFYING;
-  g_object_set (G_OBJECT (priv->source), "location", fn, NULL);
+  g_object_set (G_OBJECT (priv->source), "location", atrack->inputfile, NULL);
   if (gst_element_set_state (priv->pipeline, GST_STATE_PAUSED) == GST_STATE_CHANGE_FAILURE) {
 #if DEBUG_GST > 0
     g_message ("Supposedly failed to change gstreamer state, ignoring it as usually it does it anyways.");
@@ -795,7 +791,7 @@ get_audio_track (XfburnTranscoder *trans, const gchar *fn, GError **error)
     recreate_pipeline (tgst);
     g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_GST_TIMEOUT,
                  _("Gstreamer did not like this file (detection timed out)"));
-    return NULL;
+    return FALSE;
   }
 #if DEBUG_GST > 0
   DBG ("Got an identification result ");
@@ -803,16 +799,12 @@ get_audio_track (XfburnTranscoder *trans, const gchar *fn, GError **error)
 
   if (!priv->is_audio) {
     g_set_error (error, XFBURN_ERROR, XFBURN_ERROR_NOT_AUDIO_FORMAT,
-                 _("%s\n\nis not an audio file:\n\n%s"), fn, priv->error->message);
+                 _("%s\n\nis not an audio file:\n\n%s"), atrack->inputfile, priv->error->message);
     g_error_free (priv->error);
     priv->error = NULL;
-    return NULL;
+    return FALSE;
   }
 
-  atrack = g_new0 (XfburnAudioTrack, 1);
-  /* FIXME: when do we free inputfile?? */
-  atrack->inputfile = g_strdup (fn);
-  atrack->pos = -1;
   atrack->length = priv->duration / 1000000000;
 
   size = (off_t) floorf (priv->duration * (PCM_BYTES_PER_SECS / (float) 1000000000));
@@ -823,14 +815,15 @@ get_audio_track (XfburnTranscoder *trans, const gchar *fn, GError **error)
 
   gtrack = g_new0 (XfburnAudioTrackGst, 1);
   atrack->data = (gpointer) gtrack;
+  atrack->type = XFBURN_TYPE_AUDIO_TRACK_GST;
 
   gtrack->size = size;
 
-  return atrack;
+  return TRUE;
 }
 
 
-
+/* initialize the XfburnAudioTrack */
 static struct burn_track *
 create_burn_track (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error)
 {
@@ -972,9 +965,11 @@ finish (XfburnTranscoder *trans)
   XfburnTranscoderGst *gst = XFBURN_TRANSCODER_GST (trans);
   XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (gst);
 
+  /*
   GstState state;
   GstClock *clock;
   GstClockTime tv;
+  */
 
 #if DEBUG_GST > 0
   DBG ("Done transcoding");
@@ -983,6 +978,11 @@ finish (XfburnTranscoder *trans)
 
   priv->curr_track = NULL;
 
+  /*
+   * gstreamer doesn't even want to work with us again after getting back into
+   * the ready state. Lame. So we just recreate the pipeline.
+   * Which doesn't help either. Oh Well.
+   * FIXME: how to get gstreamer to accept state changes again after an aborted burn run?
   clock = gst_element_get_clock (priv->pipeline);
   tv = gst_clock_get_time (clock);
   g_object_unref (clock);
@@ -999,22 +999,8 @@ finish (XfburnTranscoder *trans)
     DBG ("Could not make pipeline ready, recreating it");
     recreate_pipeline (gst);
   }
-}
-
-static gboolean
-free_burning_resources (XfburnTranscoder *trans, XfburnAudioTrack *atrack, GError **error)
-{
-  /*
-  XfburnTranscoderGst *gst = XFBURN_TRANSCODER_GST (trans);
-  XfburnTranscoderGstPrivate *priv= XFBURN_TRANSCODER_GST_GET_PRIVATE (gst);
   */
-  
-  XfburnAudioTrackGst *gtrack = XFBURN_AUDIO_TRACK_GET_GST (atrack);
-  
-  g_free (gtrack);
-  atrack->data = NULL;
-
-  return TRUE;
+  recreate_pipeline (gst);
 }
 
 
